==> react-7.11.0.tgz: package/es/TopbarMobile/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Icon, ListSeparator } from "./..";
/**
 * Topbar Mobile
 * @param props
 */

var TopbarMobile =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(TopbarMobile, _React$Component);

  function TopbarMobile() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      isMobileOpen: false
    };

    _this.handleClick = function () {
      _this.setState({
        isMobileOpen: !_this.state.isMobileOpen
      });
    };

    return _this;
  }

  var _proto = TopbarMobile.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        children = _this$props.children,
        brandNode = _this$props.brandNode;
    var isMobileOpen = this.state.isMobileOpen;
    var mobileButton = React.createElement(Icon, {
      name: "list-menu_20",
      className: "cui-top-bar__mobile-menu-button",
      onClick: function onClick() {
        return _this2.setState({
          isMobileOpen: !isMobileOpen
        });
      },
      onKeyPress: this.handleKeyPress,
      tabIndex: 0,
      "aria-pressed": isMobileOpen,
      role: "button"
    });
    /* eslint-disable */

    return React.createElement("div", null, !isMobileOpen && mobileButton, React.createElement("div", {
      className: "cui-top-bar__mobile cui-tb-mobile" + ("" + (isMobileOpen ? ' open' : '')),
      onClick: this.handleClick
    }, React.createElement(Icon, {
      name: "cancel_20",
      className: "cui-tb-mobile__close",
      tabIndex: 0,
      "aria-pressed": isMobileOpen,
      role: "button"
    }), brandNode, React.createElement(ListSeparator, null), React.createElement("nav", {
      className: "cui-tb-mobile__nav"
    }, children)), React.createElement("div", {
      className: 'cui-tb-mobile__mask' + ("" + (isMobileOpen ? ' open' : '')),
      onClick: this.handleClick,
      role: "none"
    }));
  };

  return TopbarMobile;
}(React.Component);
/* eslint-enable */


TopbarMobile.displayName = 'TopbarMobile';
TopbarMobile.propTypes = {
  /**
   * Children components
   */
  children: PropTypes.node,

  /**
   * KeyPress Handler
   */
  brandNode: PropTypes.node
};
TopbarMobile.defaultProps = {
  children: null,
  brandNode: null
};
export default TopbarMobile;

==> react-8.4.0.tgz: package/es/TopbarMobile/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Icon, ListSeparator } from "./..";
/**
 * Topbar Mobile
 * @param props
 */

var TopbarMobile =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(TopbarMobile, _React$Component);

  function TopbarMobile() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      isMobileOpen: false
    };

    _this.handleClick = function () {
      _this.setState({
        isMobileOpen: !_this.state.isMobileOpen
      });
    };

    _this.handleKeyDown = function (e) {
      if (e.which === 32 || e.which === 13 || e.charCode === 32 || e.charCode === 13) {
        _this.handleClick();

        e.preventDefault();
      }
    };

    return _this;
  }

  var _proto = TopbarMobile.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        brandNode = _this$props.brandNode,
        children = _this$props.children,
        closeMenuAriaLabel = _this$props.closeMenuAriaLabel,
        openMenuAriaLabel = _this$props.openMenuAriaLabel;
    var isMobileOpen = this.state.isMobileOpen;
    var mobileButton = React.createElement(Icon, {
      name: "list-menu_20",
      buttonClassName: "cui-top-bar__mobile-menu-button",
      onClick: this.handleClick,
      ariaLabel: openMenuAriaLabel,
      "aria-pressed": isMobileOpen
    });
    return React.createElement("div", null, !isMobileOpen && mobileButton, React.createElement("div", {
      className: 'cui-top-bar__mobile cui-tb-mobile' + ("" + (isMobileOpen ? ' open' : '')),
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      role: "menu",
      tabIndex: 0
    }, React.createElement(Icon, {
      name: "cancel_20",
      buttonClassName: "cui-tb-mobile__close",
      "aria-pressed": isMobileOpen,
      onClick: this.handleClick,
      ariaLabel: closeMenuAriaLabel
    }), brandNode, React.createElement(ListSeparator, null), React.createElement("nav", {
      className: "cui-tb-mobile__nav"
    }, children)), React.createElement("div", {
      className: 'cui-tb-mobile__mask' + ("" + (isMobileOpen ? ' open' : '')),
      onClick: this.handleClick,
      role: "none"
    }));
  };

  return TopbarMobile;
}(React.Component);

TopbarMobile.displayName = 'TopbarMobile';
TopbarMobile.propTypes = {
  /** Brand Node */
  brandNode: PropTypes.node,

  /** Children components */
  children: PropTypes.node,

  /** Aria Label for close Button */
  closeMenuAriaLabel: PropTypes.string,

  /** Aria Label for open Button */
  openMenuAriaLabel: PropTypes.string
};
TopbarMobile.defaultProps = {
  brandNode: null,
  children: null,
  closeMenuAriaLabel: 'Close Menu',
  openMenuAriaLabel: 'Open Menu'
};
export default TopbarMobile;
